@@ -9,7 +9,7 @@ import sys
 
 from clu.constants.consts import APPNAME, NoDefault
 from clu.config.abc import KeyMap, NamespaceWalker
-from clu.config.ns import pack_ns, prefix_env, unpack_env, nskey_to_env
+from clu.config.ns import pack_ns, prefix_env, unpack_env, nskey_from_env, nskey_to_env
 from clu.predicates import tuplize, listify
 from clu.typology import iterlen
 from clu.exporting import Exporter
@@ -87,7 +87,7 @@ class FrozenEnviron(NamespaceWalker, clu.abstract.ReprWrapper,
         """ Get a view on the dictionary keys from the backend environment. """
         return self.environment.keys()
     
-    def inner_repr(self):
+    def inner_repr(self): # pragma: no cover
         """ Return some readable meta-information about this instance """
         prefix = prefix_env(self.appname)
         nscount = iterlen(self.namespaces())
@@ -96,7 +96,9 @@ class FrozenEnviron(NamespaceWalker, clu.abstract.ReprWrapper,
     
     def clone(self, deep=False, memo=None):
         copier = deep and copy.deepcopy or copy.copy
-        return type(self)(tree=copier(self.tree))
+        out = type(self)(appname=self.appname)
+        out.environment = copier(self.environment)
+        return out
 
 @export
 class Environ(FrozenEnviron, KeyMap, contextlib.AbstractContextManager):
@@ -145,18 +147,16 @@ class Environ(FrozenEnviron, KeyMap, contextlib.AbstractContextManager):
     def __exit__(self, exc_type=None,
                        exc_val=None,
                        exc_tb=None):
-        if self.stash:
-            try:
-                self.environment.clear()
-            finally:
-                self.environment.update(self.stash)
+        try:
+            self.environment.clear()
+        finally:
+            self.environment.update(self.stash or {})
         self.stash = None
         return exc_type is None
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
 
-
 def test():
     
     from clu.testing.utils import inline, format_environment
@@ -177,25 +177,58 @@ def test():
             nskey = pack_ns(key, *namespaces)
             assert nskey in env
     
+    @inline
+    def test_one_pt_five():
+        """ FrozenEnviron and “envwalk(…)” with ‘updates’ kwargs """
+        updates = { 'yo' : 'dogg', 'iheard' : 'you like' }
+        env = FrozenEnviron(**updates)
+        
+        for *namespaces, key, value in envwalk('clu', os.environ.copy()):
+            nskey = pack_ns(key, *namespaces)
+            assert nskey in env
+        
+        # getenv(…) key check:
+        for key in updates.keys():
+            assert env.getenv(key) == updates[key]
+        
+        # bad-key getenv(…) without default -
+        # raises a KeyError:
+        try:
+            env.getenv('wat')
+        except KeyError as exc:
+            assert 'wat' in str(exc)
+        
+        # bad-key getenv(…) with default:
+        assert env.getenv('WTF', 'HAX') == 'HAX'
+    
     @inline
     def test_two():
         """ Environ with “os.environ” and custom-dict backends """
         env = Environ()
+        fenv = env.freeze()
         nenv = env.flatten().nestify()
+        
         wat = Environ(environment={ nskey_to_env('clu', nskey) : value \
                                     for nskey, value \
                                      in nenv.flatten().items() })
+        
         assert env == wat
+        assert fenv == wat
         assert env.flatten() == nenv
+        
         assert len(env.envkeys()) >= len(env)
         assert len(wat.envkeys()) == len(wat)
+        
+        env.setenv('wtf', 'hax')
+        assert 'wtf' not in wat
+        env.unsetenv('wtf')
     
     @inline
     def test_three():
         """ FrozenEnviron low-level API """
         env = FrozenEnviron()
         
-        for key in env.envkeys():
+        for key in env.clone().envkeys():
             assert env.hasenv(key)
             assert env.getenv(key) == os.getenv(key)
         
@@ -207,9 +240,7 @@ def test():
             assert len(env) == before
             assert not env.hasenv('CLU_CTX_YODOGG')
             assert os.getenv('CLU_CTX_YODOGG') == 'I heard you are frozen'
-            # print("CLU_CTX_YODOGG:", os.getenv('CLU_CTX_YODOGG'))
         finally:
-            # os.unsetenv('CLU_CTX_YODOGG')
             del os.environ['CLU_CTX_YODOGG']
     
     @inline
@@ -230,6 +261,26 @@ def test():
         assert os.getenv('CLU_CTX_YODOGG') is None
         assert len(os.environ) == before
     
+    @inline
+    def test_four():
+        """ Check “prefix_env(…)” edge-case handling """
+        # not appname, not namespaces:
+        assert prefix_env(None) == ''
+        
+        # not appname:
+        assert prefix_env(None, 'do', 're', 'mi') == 'DO_RE_MI_'
+        
+        # not namespaces:
+        assert prefix_env('yodogg') == 'YODOGG_'
+        
+        # yes to both:
+        assert prefix_env('yodogg', 'do', 're', 'mi') == 'YODOGG_DO_RE_MI_'
+        
+        # nskey_from_env(…) checks:
+        assert nskey_from_env('YODOGG_DO_RE_MI_KEY') == ('yodogg', 'do:re:mi:key')
+        assert nskey_from_env('YODOGG_KEY') == ('yodogg', 'key')
+        assert nskey_from_env('YODOGG_') == ('yodogg', '')
+    
     @inline.diagnostic
     def show_environment():
         """ Show environment variables """
@@ -256,4 +307,4 @@ def test():
     return inline.test(100)
 
 if __name__ == '__main__':
-    sys.exit(test())
+    sys.exit(test())
\ No newline at end of file
