@@ -889,6 +889,7 @@ class Directory(BaseFSName,
     def importables(self, subdir, suffix='py',
                                   source=None,
                                   excludes=('-', '+', 'pytest',
+                                                      'legacy',
                                                       'obsolete',
                                                       'repl.py')):
         """ List the importable file-based modules found within “subdir”,
@@ -961,15 +962,11 @@ class Directory(BaseFSName,
         if self.exists:
             with os.scandir(os.path.realpath(self.name)) as iterscan:
                 yield from (k.name for k in iterscan)
-        else:
-            yield from iter(tuple())
     
     def __reversed__(self):
         if self.exists:
             with os.scandir(os.path.realpath(self.name)) as iterscan:
-                yield from (k.name for k in reversed(iterscan))
-        else:
-            yield from iter(tuple())
+                yield from (k.name for k in reversed(tuple(iterscan)))
     
     def __len__(self):
         if not self.exists:
