@@ -35,7 +35,8 @@ from clu.naming import nameof, dotpath_split, dotpath_join, qualified_name
 
 from clu.predicates import (anyattrs, attr,
                             attr_search, item_search,
-                            mro, typeof, none_function, tuplize)
+                            mro, typeof, none_function,
+                            isexpandable, tuplize)
 
 from clu.repr import stringify, hexid
 from clu.typespace import types
@@ -163,6 +164,14 @@ def appspaces_for_appname(appname):
                filter(None,
                map(get_appspace, modules.keys())))
 
+@export
+def modules_for_appname_and_appspace(appname, appspace):
+    modules = Registry.monomers.get(appname, {})
+    dotpath = dotpath_join(appname, appspace)
+    if dotpath:
+        yield from (module for module in modules.values() \
+             if str(module.qualname).startswith(dotpath))
+
 @export
 class Registry(abc.ABC, metaclass=MetaRegistry):
     
@@ -318,8 +327,6 @@ class MetaNameAndSpaces(MetaTypeRepr):
         appname = getattr(cls, 'appname', None)
         if appname is not None:
             yield from appspaces_for_appname(appname)
-        else:
-            yield from tuple()
 
 @export
 class LoaderBase(clu.abstract.AppName,
@@ -641,6 +648,18 @@ class ModuleAlias(collections.abc.Callable,
     
     __slots__ = ('origin', 'specializer')
     
+    @classmethod
+    def __class_getitem__(cls, key):
+        """ Subscripting ModuleAlias or one of its subtypes returns an
+            instance of ModuleAlias (q.v. class definition supra.),
+            used to “specialize” ModuleAlias subtypes by inserting the
+            specialization type into the ModuleBase subtypes’ MRO.
+        """
+        if isexpandable(key):
+            origin, specializer, *leftovers = key
+            return cls(origin, specializer)
+        return cls(typeof(key), None)
+    
     def __init__(self, origin, specializer):
         """ Initialize a ModuleAlias, with an origin class and a specializer type """
         if not subclasscheck(origin, ModuleBase):
@@ -651,6 +670,10 @@ class ModuleAlias(collections.abc.Callable,
         self.origin = typeof(origin)
         self.specializer = typeof(specializer)
     
+    def __getitem__(self, key):
+        """ Re-specialize a ModuleAlias instance """
+        return type(self)(self.origin, typeof(key))
+    
     def __hash__(self):
         return hash(self.origin) \
              & hash(self.specializer)
@@ -806,7 +829,7 @@ class PerApp:
         """ Return a generator over this app’s defined appspaces """
         yield from self.modules.keys()
     
-    def __repr__(self):
+    def __repr__(self): # pragma: no cover
         return stringify(self,
                     type(self).fields,
                          try_callables=False)
@@ -1252,13 +1275,6 @@ def test():
         print("qualified module name:", qualified_name(module))
         print("module of module:", moduleof(module))
     
-    @inline.precheck
-    def show_module_wtf_hax():
-        def mod():
-            lam = lambda: None
-            return moduleof(lam)
-        print("module:", mod())
-    
     @inline.precheck
     def show_module_fucking_seriously():
         from clu.exporting import thismodule
@@ -1377,6 +1393,8 @@ def test():
         
         assert isinstance(derived, Module)
         assert derived.yo == 'dogg'
+        assert derived.yodogg() == "I heard you like"
+        assert derived.nodogg() is None
         
         for attname in dir(derived):
             assert hasattr(derived, attname)
@@ -1443,6 +1461,8 @@ def test():
         assert not hasattr(overridden, 'targets')       # lowercase: fallback raises KeyError
         assert not hasattr(overridden, 'target_dicts')  # lowercase: fallback raises KeyError
         assert hasattr(overridden, '_targets')          # attribute found normally
+        
+        assert dir(overridden)
     
     @inline
     def test_five_point_eight():
@@ -1473,6 +1493,8 @@ def test():
         assert not hasattr(overridden, 'target_dicts')
         assert hasattr(overridden, '_targets')
         
+        assert dir(overridden)
+    
     @inline
     def test_six():
         """ Polymer-type caching and “initialize_types(…)” checks """
