@@ -170,7 +170,7 @@ def explain(thing, width=None):
 
 try:
     from instakit.utils.static import asset
-except (ImportError, SyntaxError, TypeError):
+except (ImportError, SyntaxError, TypeError): # pragma: no cover
     pass
 else:
     # Extend `__all__`:
