@@ -84,6 +84,7 @@ def codecov(session):
                        'clu.constants.consts',
                        'clu',
                        'clu.version',
+                       'clu.dispatch',
                        'clu.fs.appdirectories',
                        'clu.repl.banners',
                        'clu.repl.columnize',
@@ -102,7 +103,8 @@ def codecov(session):
     coveragefile.copy('.coverage')
     
     # Run “pytest” with the “pytest-cov” plugin:
-    session.run('pytest', '-p', 'pytest_cov', '--cov-append',
+    session.run('pytest', '-p', 'pytest_cov', '--cov=clu',
+                                              '--cov-append',
                                               '--cov-report=xml:coverage.xml',
                                               '--no-cov-on-fail',
                                               'tests/')
