@@ -23,6 +23,7 @@ class TestImporting(object):
         assert subscript != ModuleAlias(Module, ProxyModule)
         assert not (subscript == None)
         assert subscript != None
+        assert hash(subscript) == hash(ModuleAlias(ProxyModule, Module))
         
         reprstring = "ModuleAlias(origin=‘<class-module “ProxyModule”>’, " \
                      "specializer=’<class-module “clu.app.Module”>’)"
@@ -53,6 +54,42 @@ class TestImporting(object):
             ModuleAlias(Module, 'wat')
         assert "Specialization requires a Module type" in str(exc.value)
     
+    def test_modulealias_respecialization_reprs(self):
+        from clu.importing import ModuleAlias, ModuleBase, Module
+        
+        reprstring = "<class “clu.importing.ModuleAlias”>"
+        
+        assert repr(ModuleAlias) == reprstring
+        
+        reprstring = "ModuleAlias(origin=‘<class-module “ModuleBase”>’, " \
+                     "specializer=’<class-module “clu.app.Module”>’) @ 0x"
+        
+        assert repr(ModuleBase[Module]).startswith(reprstring)
+        assert repr(ModuleBase[Module][Module]).startswith(reprstring)
+        assert repr(ModuleAlias[ModuleBase, Module]).startswith(reprstring)
+        assert repr(ModuleAlias(ModuleBase, Module)).startswith(reprstring)
+        assert repr(ModuleAlias[ModuleBase][Module]).startswith(reprstring)
+        assert repr(ModuleAlias[ModuleBase, None][Module]).startswith(reprstring)
+        assert repr(ModuleAlias(ModuleBase, None)[Module]).startswith(reprstring)
+        
+        reprstring = "ModuleAlias(origin=‘<class-module “clu.app.Module”>’, " \
+                     "specializer=’None’) @ 0x"
+        
+        assert repr(Module[None]).startswith(reprstring)
+        assert repr(ModuleAlias[Module]).startswith(reprstring)
+        assert repr(ModuleAlias[Module, None]).startswith(reprstring)
+        assert repr(ModuleAlias(Module, None)).startswith(reprstring)
+        assert repr(ModuleAlias[Module, None][None]).startswith(reprstring)
+        assert repr(ModuleAlias(Module, None)[None]).startswith(reprstring)
+        
+        with pytest.raises(TypeError) as exc:
+            assert repr(ModuleAlias[None, None]).startswith(reprstring)
+        assert "Specialization requires a Module type" in str(exc.value)
+        
+        with pytest.raises(TypeError) as exc:
+            assert repr(ModuleAlias[None][Module, None]).startswith(reprstring)
+        assert "Specialization requires a Module type" in str(exc.value)
+    
     def test_proxy_module_for_reals(self, consts):
         from clu.importing import ProxyModule, Module, Registry
         
@@ -361,9 +398,19 @@ class TestImporting(object):
         assert len(polymers[consts.APPNAME].modules) == 1
         assert iterlen(polymers.all_appspaces()) == 1
         
+        # Check get_finder(…) and get_loader(…)
         assert polymers.get_finder(consts.APPNAME) is Finder
         assert polymers.get_loader(consts.APPNAME) is Loader
         
+        # Check error conditions for get_finder(…) and get_loader(…)
+        with pytest.raises(ValueError) as exc:
+            polymers.get_finder('WTF')
+        assert "no PerApp instance" in str(exc.value)
+        
+        with pytest.raises(ValueError) as exc:
+            polymers.get_loader('WTF')
+        assert "no PerApp instance" in str(exc.value)
+        
         new_appspace = 'new'
         
         NewModule, NewFinder, NewLoader = initialize_new_types(consts.APPNAME,
@@ -382,6 +429,31 @@ class TestImporting(object):
         assert len(polymers[consts.APPNAME].modules) == 2
         assert iterlen(polymers.all_appspaces()) == 2
         
+        # Check error conditions for add_module(…)
+        with pytest.raises(ValueError) as exc:
+            polymers.add_module(NewModule,
+                                appname=consts.APPNAME,
+                                appspace=None)
+        assert "an appspace is required" in str(exc.value)
+        
+        with pytest.raises(ValueError) as exc:
+            polymers.add_module(None,
+                                appname=consts.APPNAME,
+                                appspace=new_appspace)
+        assert "a module is required" in str(exc.value)
+        
+        with pytest.raises(ValueError) as exc:
+            polymers.add_module(NewModule,
+                                appname='WTF',
+                                appspace=new_appspace)
+        assert "no PerApp instance" in str(exc.value)
+        
+        with pytest.raises(NameError) as exc:
+            polymers.add_module(NewModule,
+                                appname=consts.APPNAME,
+                                appspace=new_appspace)
+        assert "module already exists in" in str(exc.value)
+        
         perapp = polymers[consts.APPNAME]
         
         assert perapp.appname == consts.APPNAME
