@@ -2,7 +2,7 @@
 from __future__ import print_function
 from datetime import datetime
 
-from clu.config.env import EnvBase
+from clu.config.base import EnvBase
 from clu.config.fieldtypes import fields
 from clu.config.formats import JsonFileBase, TomlFileBase
 from clu.config.settings import Schema
