@@ -8,7 +8,7 @@ export = exporter.decorator()
 
 @export
 def youlike():
-    pass
+    return "registries"
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
